==> dojo-1.10.6.tgz: package/cldr/nls/hr/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "sada",
	"field-weekday": "Dan u tjednu",
	"field-wed-relative+0": "ova srijeda",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-tue-relative+-1": "prošli utorak",
	"dateFormat-long": "d. MMMM y. G",
	"field-fri-relative+-1": "prošli petak",
	"field-wed-relative+-1": "prošla srijeda",
	"dateFormatItem-yyyyQQQ": "QQQ y. G",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, d. M. y. G",
	"field-thu-relative+-1": "prošli četvrtak",
	"dateFormatItem-Md": "d. M.",
	"field-era": "Era",
	"field-year": "Godina",
	"dateFormatItem-yyyyMMMM": "LLLL y. G",
	"field-hour": "Sat",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-thu-relative+0": "ovaj četvrtak",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "prekosutra",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-M": "L.",
	"dateFormatItem-yyyyMMM": "LLL y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-sun-relative+0": "ova nedjelja",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-minute": "Minuta",
	"field-dayperiod": "Prijepodne/popodne",
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "jučer",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "prekjučer",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d. M.",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "Dan",
	"field-zone": "Vremenska zona",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "prošle godine",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-yyyyMd": "d. M. y. G",
	"field-month": "Mjesec",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"dateFormat-short": "d.M.y. GGGGG",
	"field-second": "Sekunda",
	"field-sat-relative+-1": "prošla subota",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Tjedan",
	"dateFormat-medium": "d. M. y. G",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošli tjedan",
	"dateFormatItem-yyyyM": "M. y. G",
	"field-year-relative+1": "sljedeće godine",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/hr/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "sada",
	"field-weekday": "Dan u tjednu",
	"field-wed-relative+0": "ova srijeda",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-tue-relative+-1": "prošli utorak",
	"dateFormat-long": "d. MMMM y. G",
	"field-fri-relative+-1": "prošli petak",
	"field-wed-relative+-1": "prošla srijeda",
	"dateFormatItem-yyyyQQQ": "QQQ y. G",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE, d. MMMM y. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y. GGGGG",
	"field-thu-relative+-1": "prošli četvrtak",
	"dateFormatItem-Md": "dd.MM.",
	"field-era": "Era",
	"field-year": "Godina",
	"dateFormatItem-yyyyMMMM": "LLLL y. G",
	"field-hour": "Sat",
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-thu-relative+0": "ovaj četvrtak",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "prekosutra",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-yyyyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-M": "L.",
	"dateFormatItem-yyyyMMM": "LLL y. G",
	"dateFormatItem-yyyyMMMd": "d. MMM y. G",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-sun-relative+0": "ova nedjelja",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-minute": "Minuta",
	"field-dayperiod": "AM/PM",
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "jučer",
	"dateFormatItem-h": "hh a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "prekjučer",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, dd.MM.",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "Dan",
	"field-zone": "Vremenska zona",
	"dateFormatItem-y": "y. G",
	"field-year-relative+-1": "prošle godine",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormatItem-yyyyMd": "dd.MM.y. GGGGG",
	"field-month": "Mjesec",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"dateFormat-short": "dd.MM.y. GGGGG",
	"field-second": "Sekunda",
	"field-sat-relative+-1": "prošla subota",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"dateFormatItem-Ed": "E, d.",
	"field-week": "Tjedan",
	"dateFormat-medium": "d. M. y. G",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošli tjedan",
	"dateFormatItem-yyyyM": "MM.y. GGGGG",
	"field-year-relative+1": "sljedeće godine",
	"dateFormatItem-yyyyQQQQ": "QQQQ y. G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"dateFormatItem-yyyy": "y. G",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan"
}
//end v1.x content
);
